	program test_uwiremis
	
!---------------------------------------------------------------------
!	test program to show how to get instrument specific IR land surface 
!       emissivity from the UW/CIMSS  Global IR land Surface Emissvity Database 
!       or also called as UW BF (Baseline Fit) emissivity database 
!       (Seemann et. al, 2008, http://cimss.ssec.wisc.edu/iremis)
!	The program calls the UW HSR emissivity Algorithm (UWIREMIS library) 
!       (Borbas et al. 2007,http://cimss.ssec.wisc.edu/iremis) 
!	for spectral "interpolation", then bilinear interpolation was used from the 
!       two closest sectral points to get the instrument specific IR emissivity spectra. 
!
!
! 	This sample/test code (test_uwiremis.F90) runs for IASI instrument at two geological locations.
!	It calls  two subroutines: uwiremis_inint.F90 and uwiremis.F90 and writes 
!	out the two resulting instrument specific emissivity spectra in  a text file. 
!
!
!    CREATED by: Eva Borbas UW/CIMSS
!
!    HISTORY: 
!            Version 0.91 delivery: April 2009 
!
!    NOTE: This algorithm was released to be useful, but without any warranty.
!
!---------------------------------------------------------------------

	use uwiremis_module 
	
	implicit none

	
	INTEGER i,nchs
	INTEGER, PARAMETER :: max_nchs=9000
	INTEGER, PARAMETER :: nchs_iasi=8461	
	INTEGER, PARAMETER :: nprof=2	

        real*4 instr_wn(max_nchs),instr_em(nprof,max_nchs)   !outputs
        real*4 instr_emflag(nprof)                           !outputs
		
	real prof_lat(nprof),prof_lon(nprof)	
 	
	data prof_lat/28.62,49.3/
        data prof_lon/15.12,-102.3/

!------------------------------------
! calculating IASI frequencies		
!------------------------------------

	nchs=nchs_iasi
	do i=1,nchs
		instr_wn(i)=645.0+(i-1)*0.25
	enddo
			
!-------------------------------------------------------------------------------
!  call the uwiremis_init for initialize the UW HSR emissivity algorithm and 
!  reads in the UW BF emissivity database for a given year (2006) and month (7)
!--------------------------------------------------------------------------------
	
	call uwiremis_init(2006,7) 

!----------------------------------------------------------------------------------------------
!  call the uwiremis subroutine to compute the hsr emissivity spectra from the 10 hinge points 
!  and create instrument specific emissivity
!----------------------------------------------------------------------------------------------
     
        do i=1,nprof
		call uwiremis(nchs,prof_lat(i),prof_lon(i),instr_wn(1:nchs), &  ! inputs
		instr_em(i,1:nchs),instr_emflag(i))                            ! outputs
 	enddo

!-------------------------
! write out the results
!-------------------------

	open(1,file='../output/testresults_uwiremis.txt')
	
	do i=1,nchs
		write(1,'(3f8.3)') instr_wn(i),instr_em(1,i),instr_em(2,i)
	enddo
 	
	stop
 	end

    
