       subroutine uwiremis(nchs,lat,lon,instr_wavenum, & ! inputs
       instr_emis,instr_emis_flag)                       ! outputs

!------------------------------------------------------------------------------
!    Copyright (C) 2008  Eva E Borbas
!    University of Wisconsin-Madison, SSEC/CIMSS 
!
!     The uwiremis subroutine is the main algorithm of the UW HSR algorithm. 
!     It computes IR emissivity for a given location and instrument frequencies
!     from the UW BF IR Global Emissivty data (at 10 hinge points) (http://cimss.ssec.wisc.edu/iremis/)
!     and labratory measurements using principal component analyses.
!     It first calls  the uwiremis_recon_hsremis.F90 subroutine to compute the hsr  
!     (with 416 spectral points) emissivity spectra from the 10 hinge points.
!     Second, it calls the uwiremis_get_wavenum.F90 subroutine to select the instrument specific emissivity spectra.  
!     The uwiremie_inint.F subroutine needs to be run before the uwiremis.f subroutine. 
!
!    CREATED by: Eva Borbas UW/CIMSS
!
!    HISTORY: 
!            Version 0.91 delivery: April 2009 
!
!    NOTE: This algorithm was released to be useful, but without any warranty.
!------------------------------------------------------------------------------
       Use uwiremis_module

        implicit none


        integer, intent(in) ::  nchs
        Real,    Intent(in)    :: lat, lon, instr_wavenum(nchs)
        Real,    Intent(out)   :: instr_emis(nchs)
        Integer, Intent(out)   :: instr_emis_flag

        real*4 bfem(hngpnts)
        real*4 hsremis(numwave)
 
!        integer j     
        
        integer gridy, gridx
        
        real hkod
        data hkod/-999./
  	     
!  diagnostic print
!   write(*,*) 'uwiremis input: ', nchs,lat,lon
!   write(*,*) 'instr_wavenum=',instr_wavenum

!-----------------------------------------
! finding the closest emis grid point
!-----------------------------------------

        gridy = int(abs(bfemis_ygrid1-lat)/bfemis_gridres)+1
        gridx = int(abs(bfemis_xgrid1-lon)/bfemis_gridres)+1
	
!  diagnostic print
!	write(*,*) bfemis_ygrid1,bfemis_xgrid1,bfemis_gridres
!	write(*,*) lat, lon, gridy,gridx
                                
!------------------------------------------------
!  assign the BFemis and flag from the database
!------------------------------------------------

             instr_emis_flag=emis_flag(gridy,gridx)
             instr_emis(:)=hkod   
        

             if(instr_emis_flag.gt.0) then
       
                    bfem=emis(:,gridy,gridx)
         
!  diagnostic print
!		     do j=1,hngpnts	
!                      write(*,*) 'bfem=', bfem(j)
!		      enddo	
        
!-------------------------
! run uwiremis_recon_hsremis.F90 to compute the hsr emissivity spectra from the 10 hinge points
!-------------------------

                    call uwiremis_recon_hsremis(bfem, hsremis)
     
!  diagnostic print
!BCR                do j=1,numwave
!BCR                  write(*,'(2f9.3)') hsr_wavenum(j), hsremis(j)
!BCR                enddo

!-------------------------
! create instrument specific emissiviy
!-------------------------
 
                    call uwiremis_get_wavenum(hsremis,nchs, &
                                        instr_wavenum,instr_emis)


              endif

!  diagnostic print
!BCR           do j=1,nchs
!BCR                  write(*,'(2f8.2)') instr_wavenum(j), instr_emis(j)
!BCR           enddo
!BCR           write(*,'(2f10.3,2i6,f10.4)') lat,lon,gridy,gridx,instr_emis(1)    
        
!        instr_em = instr_emis

        return
        end

    
