      SUBROUTINE uwiremis_get_wavenum &
      (hsremis,nchs,instr_wavenum,instr_emis)       

!------------------------------------------------------------------------------
!    Copyright (C) 2008  Eva E Borbas
!    University of Wisconsin-Madison, SSEC/CIMSS 
!
!       subroutine to find the closest wavenumber from the UW HSR emissivity spectra 
!       for the array of the instrument CWN and assign the instrument emissivity by choosing the 
!       closest spectral point value or bilinear interpolating  between the two closest spectral point values
!
!    CREATED by: Eva Borbas UW/CIMSS
!
!    HISTORY: 
!            Version 0.91 delivery: April 2009 
!
!    NOTE: This algorithm was released to be useful, but without any warranty.
!------------------------------------------------------------------------------
       Use uwiremis_module

        implicit none

        integer j,k
        integer nchs
        real*4 hsremis(numwave)

        real*4 instr_wavenum(nchs)
        real*4 instr_emis(nchs)
        real*4 dist(numwave)
        real*4 mindist(nchs)
        integer ind_mindist(nchs)
        
        real*4 dwvnum1,dwvnum2,hsremis1,hsremis2,dwvsum

        real*4 hkod
        data hkod/-999./

        instr_emis=hkod

 
 
        do j=1,nchs
	
        if(instr_wavenum(j).le.hsr_wavenum(1)) then
	
	       instr_emis(j)=hsremis(1)
	
	elseif(instr_wavenum(j).ge.hsr_wavenum(numwave)) then     
	
 	       instr_emis(j)=hsremis(numwave)

        else	       
                
               mindist(j)=100.
               ind_mindist(j)=100000
                                                                        
               do k=1,numwave
                        
                        dist(k)=abs(instr_wavenum(j)-hsr_wavenum(k))
                                
                        if(dist(k).le.mindist(j)) then
                                
                        mindist(j)=dist(k)
                        ind_mindist(j)=k
                                
                        endif
               enddo   
                        
!--------------------------------
! assign instrument emissivity
!--------------------------------
!  closest spectral point
                
!               instr_emis(j)=hsremis(ind_mindist(j))

! or  bilinear mean of the two closest spectral points

                k=1 
                dwvnum1=0
                dwvnum2=0
                hsremis1=0
                hsremis2=0
	       
                if(instr_wavenum(j).le.hsr_wavenum(ind_mindist(j))) k=-1
                                
                dwvnum1=dist(ind_mindist(j))
                dwvnum2=dist(ind_mindist(j)+k)
                
		hsremis1=dwvnum1*hsremis(ind_mindist(j)+k)
                hsremis2=dwvnum2*hsremis(ind_mindist(j))
                
		dwvsum=dwvnum1+dwvnum2
                                
                instr_emis(j)=(hsremis1 + hsremis2) / dwvsum
                                                         
        endif
	
	enddo

        return
        end

