       subroutine uwiremis_init(iyear,imonth)

!------------------------------------------------------------------------------
!    Copyright (C) 2008  Eva E Borbas
!    University of Wisconsin-Madison, SSEC/CIMSS 
!
!    initialize the uwiremis.F90 algorithm by (1) reading in the UW BF IR Global
!    Emissivty data and (2)  the eigenvectors of the laboratory spectra, and (3) make some
!    precalculations for the PCA regression
!
!    CREATED by: Eva Borbas UW/CIMSS
!
!    HISTORY: 
!            Version 0.91 delivery: April 2009 
!
!    NOTE: This algorithm was released to be useful, but without any warranty.
!------------------------------------------------------------------------------

        use uwiremis_module
            
        implicit none

        integer, intent(in) :: imonth
        integer, intent(in) :: iyear

        INTEGER i,j,k
        INTEGER, PARAMETER :: nmonth=12

        real*8 A(numpcs,hngpnts),AT(hngpnts,numpcs)
        real*8 B(numpcs,numpcs),C(numpcs,numpcs)
        
        character*300 fn
        CHARACTER*4 cyear
        CHARACTER*3 nday(nmonth), nday_leap(nmonth)
        CHARACTER*3 jday

         data nday/'001', '032','060','091','121','152','182','213','244','274','305','335'/
         data nday_leap/'001', '032','061','092','122','153','183','214','245','275','306','336'/
 
         write(cyear,'(i4)') iyear
         
	 if (mod(iyear,4).eq.0) then
	 	jday=nday_leap(imonth)
	 else
	 	jday=nday(imonth)
	 endif
        
!-------------------------
! reading bfemis database
!-------------------------
          fn='../data/global_emis_inf10_monthFilled_MYD11C3.A'// &
              cyear//jday//'.nc'
	 
          write(*,*) 'fn=   '//trim(fn)
          
	  call uwiremis_read_db(trim(fn))
        
!--------------------------------------------------------------
! initialize HSRemis - reading eigenvectors of the lab spectra
!--------------------------------------------------------------
          fn='../data/UWiremis_labeigvects.nc'
!          write(*,*) 'fn=   '//trim(fn)
          
	  call uwiremis_read_labeigvects(trim(fn))
        
!--------------------------------------------------
! compute D matrix for HSR emissivity construction
!--------------------------------------------------

! define matrix A

!	A=pcu_modres(1:numpcs,1:hngpnts)
       do i=1,numpcs
         do j=1,hngpnts
                A(i,j)=pcu_modres(i,j)
         enddo
        enddo
           
! calculate transpose matrix A : AT [6X4]         

	AT=transpose(A)


!  B=A*A' [4X6]X[6X4]   first: row second: column
        
	B=0
        
	do i=1,numpcs
         do j=1,numpcs
          do k=1,hngpnts  
                B(i,j)=B(i,j)+A(i,k)*AT(k,j)
          enddo
         enddo    
        enddo   


! computing inverse of B

        call SYMVRT(B,C,numpcs,numpcs)

                
! compute D=A'*inv(A*A')=A'*inv(B)= AT * C [6X4] * [4X4]

        D=0
        
        do i=1,hngpnts
         do j=1,numpcs
          do k=1,numpcs                           
                D(i,j)=D(i,j)+AT(i,k)*C(k,j)
          enddo
         enddo    
        enddo   

        

! diagnostic print
        do i=1,hngpnts
            write(*,'(10f10.4)') D(i,:)
        enddo   

     
        return
        end

    
